@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000028';
+$LWP::ConsoleLogger::VERSION = '0.000029';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -486,7 +486,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000028
+version 0.000029
 
 =head1 SYNOPSIS
 
@@ -499,13 +499,12 @@ version 0.000028
             my $content_type = shift;
 
             # mangle content here
-            ...
+            # ...
 
-                return $content;
+            return $content;
         },
     );
 
-    my $ua = LWP::UserAgent->new();
     $ua->default_header(
         'Accept-Encoding' => scalar HTTP::Message::decodable() );
 
@@ -517,15 +516,14 @@ version 0.000028
     # now watch debugging output to your screen
     $ua->get( 'http://nytimes.com/' );
 
-    #################################################################
+Or start the easy way.
 
-    # or start the easy way
     use LWP::ConsoleLogger::Easy qw( debug_ua );
     use WWW::Mechanize;
 
     my $mech           = WWW::Mechanize->new;   # or LWP::UserAgent->new() etc
     my $console_logger = debug_ua( $mech );
-    $mech->get( $some_url );
+    $mech->get( 'https://metacpan.org' );
 
     # now watch the console for debugging output
     # turn off header dumps
@@ -533,8 +531,7 @@ version 0.000028
 
     $mech->get( $some_other_url );
 
-    #################################################################
-    # sample output might look like this
+Sample output might look like this.
 
     GET http://www.nytimes.com/2014/04/24/technology/fcc-new-net-neutrality-rules.html
 
@@ -718,6 +715,32 @@ HTML content to make it easier to detect changes in the body of the page.
 Try to make sure that your content mangling doesn't return broken HTML as that
 may not play with with L<HTML::Restrict>.
 
+=head2 request_callback
+
+Use this handler to set up console logging on your requests.
+
+    my $ua = LWP::UserAgent->new;
+    $ua->add_handler(
+        'request_send',
+        sub { $console_logger->request_callback(@_) }
+    );
+
+This is done for you by default if you set up your logging via
+L<LWP::ConsoleLogger::Easy>.
+
+=head2 response_callback
+
+Use this handler to set up console logging on your responses.
+
+    my $ua = LWP::UserAgent->new;
+    $ua->add_handler(
+        'response_done',
+        sub { $console_logger->response_callback(@_) }
+    );
+
+This is done for you by default if you set up your logging via
+L<LWP::ConsoleLogger::Easy>.
+
 =head2 text_pre_filter( sub { ... } )
 
 Subroutine reference.  This allows you to manipulate text before it is dumped.
@@ -782,6 +805,8 @@ module and you can't find an appropriate test, do add something to the example
 folder (either a new script or alter an existing one), so that I can see what
 your patch does.
 
+=for Pod::Coverage BUILD
+
 =head1 AUTHOR
 
 Olaf Alders <olaf@wundercounter.com>
